import request from '@/utils/request'

// 查询部门列表
export function listOrgan(query) {
  return request({
    url: '/system/organ/list',
    method: 'get',
    params: query
  })
}

export function allStatsicList() {
  return request({
    url: '/system/organ/allStatsicList',
    method: 'get'
  })
}
// 查询部门列表（排除节点）
export function listOrganExcludeChild(deptId) {
  return request({
    url: '/system/organ/list/exclude/' + deptId,
    method: 'get'
  })
}

// 查询部门详细
export function getOrgan(deptId) {
  return request({
    url: '/system/organ/' + deptId,
    method: 'get'
  })
}

// 查询部门下拉树结构
export function treeselect() {
  return request({
    url: '/system/organ/treeselect',
    method: 'get'
  })
}

// 根据角色ID查询部门树结构
export function roleOrganTreeselect(roleId) {
  return request({
    url: '/system/organ/roleOrganTreeselect/' + roleId,
    method: 'get'
  })
}

// 新增部门
export function addOrgan(data) {
  return request({
    url: '/system/organ',
    method: 'post',
    data: data
  })
}

// 修改部门
export function updateOrgan(data) {
  return request({
    url: '/system/organ',
    method: 'put',
    data: data
  })
}

// 删除部门
export function delOrgan(deptId) {
  return request({
    url: '/system/organ/' + deptId,
    method: 'delete'
  })
}
