<!-- <template>
  <div class="app-container" style="display: flex;flex-direction: column;">
    <el-card shadow="always">
      <el-form :inline="true">
        <el-form-item label="机构名称">
          <el-input
            v-model="queryParams.name"
            placeholder="请输入机构名称"
            clearable
            size="small"
            @keyup.enter.native="handleQuery"
          />
        </el-form-item>
        <el-form-item label="机构类型">
          <el-select v-model="queryParams.type" placeholder="机构类型" clearable size="small">
            <el-option
              v-for="dict in typeOptions"
              :key="dict.dictValue"
              :label="dict.dictLabel"
              :value="dict.dictValue"
            />
          </el-select>
        </el-form-item>
        <el-form-item label="状态">
          <el-select v-model="queryParams.state" placeholder="机构状态" clearable size="small">
            <el-option
              v-for="dict in stateOptions"
              :key="dict.dictValue"
              :label="dict.dictLabel"
              :value="dict.dictValue"
            />
          </el-select>
        </el-form-item>
        <el-form-item>
          <el-button
            class="filter-item"
            type="primary"
            icon="el-icon-search"
            size="small"
            @click="handleQuery"
          >搜索
          </el-button>
          <el-button
            class="filter-item"
            type="primary"
            icon="el-icon-plus"
            size="small"
            @click="handleAdd"
            v-hasPermi="['system:dept:add']"
          >新增
          </el-button>
        </el-form-item>
      </el-form>
    </el-card>
    <el-card shadow="always" style="flex: 1">
      <el-table
        v-loading="loading"
        :data="deptList"
        row-key="id"
        default-expand-all
        :tree-props="{children: 'children', hasChildren: 'hasChildren'}"
        border
      >
        <el-table-column prop="name" label="机构名称" width="260">
          <template slot-scope="scope">
            <svg-icon icon-class="peoples" class-name="code" v-if="scope.row.type == '001'"/>
            <svg-icon icon-class="tree-table" v-if="scope.row.type == '002'"/>
            <svg-icon icon-class="international" v-if="scope.row.type == '003'"/>
            <svg-icon icon-class="app-mgr" v-if="scope.row.type == '004'"/>
            {{ scope.row.name }}
          </template>
        </el-table-column>
        <el-table-column prop="address" label="机构地址" width="200"></el-table-column>
        <el-table-column prop="type" label="类型" width="80" :formatter="typeFormat"></el-table-column>
        <el-table-column prop="userName" label="负责人" width="200"></el-table-column>
        <el-table-column prop="phone" label="联系方式" width="200"></el-table-column>
        <el-table-column prop="state" label="状态" width="80">
          <template slot-scope="scope">
            <el-tag type="success" v-if="scope.row.state == 0">{{ stateFormat(scope.row) }}</el-tag>
            <el-tag type="warning" v-else>{{ stateFormat(scope.row) }}</el-tag>
          </template>

        </el-table-column>
        <el-table-column label="创建时间" align="center" prop="createTime" width="200">
          <template slot-scope="scope">
            <span>{{ parseTime(scope.row.createTime) }}</span>
          </template>
        </el-table-column>
        <el-table-column label="操作" align="center" class-name="small-padding fixed-width">
          <template slot-scope="scope">
            <el-button
              type="text"
              icon="el-icon-edit"
              @click="handleUpdate(scope.row)"
              v-hasPermi="['system:dept:edit']"
            >修改
            </el-button>
            <el-button

              type="text"
              icon="el-icon-plus"
              v-if="scope.row.type != '003'"
              @click="handleAdd(scope.row)"
              v-hasPermi="['system:dept:add']"
            >新增
            </el-button>
            <el-button
              v-if="scope.row.parentId != 0"

              type="text"
              icon="el-icon-delete"
              @click="handleDelete(scope.row)"
              v-hasPermi="['system:dept:remove']"
            >删除
            </el-button>
          </template>
        </el-table-column>
      </el-table>
    </el-card>
    <!-- 添加或修改机构对话框 -->
    <el-dialog :title="title" :visible.sync="open" width="600px" append-to-body>
      <el-form ref="form" :model="form" :rules="rules" label-width="80px">
        <el-row>
<!--          <el-col :span="24" v-if="form.parentId !== '0'">
            <el-form-item label="上级机构" prop="parentId">
              <treeselect v-model="form.parentId" :options="deptOptions" :normalizer="normalizer" placeholder="选择上级机构"/>
            </el-form-item>
          </el-col>-->
          <el-col :span="12">
            <el-form-item label="机构名称" prop="name">
              <el-input v-model="form.name" placeholder="请输入机构名称" maxlength="30"/>
            </el-form-item>
          </el-col>
          <el-col :span="12">
            <el-form-item label="机构类型" prop="type">
              <el-select v-model="form.type" placeholder="机构类型" clearable size="small">
                <el-option
                  v-for="dict in typeOptions"
                  :key="dict.dictValue"
                  :label="dict.dictLabel"
                  :value="dict.dictValue"
                />
              </el-select>
            </el-form-item>
          </el-col>
          <el-col :span="12">
            <el-form-item label="负责人" prop="userName">
              <el-input v-model="form.userName" placeholder="请输入负责人" maxlength="20"/>
            </el-form-item>
          </el-col>
          <el-col :span="12">
            <el-form-item label="联系电话" prop="phone">
              <el-input v-model="form.phone" placeholder="请输入联系电话" maxlength="11"/>
            </el-form-item>
          </el-col>
          <el-col :span="24">
            <el-form-item label="地址" prop="email">
              <el-input v-model="form.address" placeholder="请输入地址" maxlength="50"/>
            </el-form-item>
          </el-col>
          <el-col :span="12">
            <el-form-item label="机构状态">
              <el-radio-group v-model="form.state">
                <el-radio
                  v-for="dict in stateOptions"
                  :key="dict.dictValue"
                  :label="dict.dictValue"
                >{{ dict.dictLabel }}
                </el-radio>
              </el-radio-group>
            </el-form-item>
          </el-col>
        </el-row>
      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button type="primary" @click="submitForm">确 定</el-button>
        <el-button @click="cancel">取 消</el-button>
      </div>
    </el-dialog>
  </div>
</template>

<script>
import {listOrgan, getOrgan, delOrgan, addOrgan, updateOrgan, listOrganExcludeChild} from "@/api/system/organ";
import Treeselect from "@riophae/vue-treeselect";
import "@riophae/vue-treeselect/dist/vue-treeselect.css";

export default {
  name: "Organ",
  components: {Treeselect},
  data() {
    return {
      // 遮罩层
      loading: true,
      // 表格树数据
      deptList: [],
      // 机构树选项
      deptOptions: [],
      // 弹出层标题
      title: "",
      // 是否显示弹出层
      open: false,
      typeOptions: [],
      // 状态数据字典
      stateOptions: [],
      // 查询参数
      queryParams: {
        name: undefined,
        state: undefined
      },
      // 表单参数
      form: {},
      // 表单校验
      rules: {
        parentId: [
          {required: true, message: "上级机构不能为空", trigger: "blur"}
        ],
        name: [
          {required: true, message: "机构名称不能为空", trigger: "blur"}
        ],
        type: [
          {required: true, message: "机构类型不能为空", trigger: "blur"}
        ],
        orderNum: [
          {required: true, message: "菜单顺序不能为空", trigger: "blur"}
        ],
        email: [
          {
            type: "email",
            message: "'请输入正确的邮箱地址",
            trigger: ["blur", "change"]
          }
        ],
        phone: [
          {
            pattern: /^1[3|4|5|6|7|8|9][0-9]\d{8}$/,
            message: "请输入正确的手机号码",
            trigger: "blur"
          }
        ]
      }
    };
  },
  created() {
    this.getList();
    this.getDicts("sys_normal_disable").then(response => {
      this.stateOptions = response.data;
    });
    this.getDicts("sys_organ_type").then(response => {
      this.typeOptions = response.data;
    });
  },
  methods: {
    /** 查询机构列表 */
    getList() {
      this.loading = true;
      listOrgan(this.queryParams).then(response => {
        this.deptList = this.handleTree(response.rows, "id");
      }).finally(() => {
        this.loading = false;
      });
    },
    /** 转换机构数据结构 */
    normalizer(node) {
      if (node.children && !node.children.length) {
        delete node.children;
      }
      return {
        id: node.id,
        label: node.name,
        children: node.children
      };
    },
    // 字典状态字典翻译
    stateFormat(row, column) {
      return this.selectDictLabel(this.stateOptions, row.state);
    },
    // 字典状态字典翻译
    typeFormat(row, column) {
      return this.selectDictLabel(this.typeOptions, row.type);
    },
    // 取消按钮
    cancel() {
      this.open = false;
      this.reset();
    },
    // 表单重置
    reset() {
      this.form.id = undefined
      // this.form = {
      //   id: undefined,
      //   parentId: undefined,
      //   name: undefined,
      //   orderNum: 0,
      //   leader: undefined,
      //   phone: undefined,
      //   email: undefined,
      //   state: "0"
      // };
      // this.resetForm("form");
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.getList();
    },
    /** 新增按钮操作 */
    handleAdd(row) {
      this.reset();
      if (row != undefined) {
        this.form.parentId = row.id;
      }
      this.open = true;
      this.title = "添加机构";
      listOrgan().then(response => {
        this.deptOptions = this.handleTree(response.rows, "id");
        console.log(JSON.stringify(this.deptOptions))
      });
    },
    /** 修改按钮操作 */
    handleUpdate(row) {
      this.reset();
      getOrgan(row.id).then(response => {
        this.form = response;
        this.open = true;
        this.title = "修改机构";
      });
      listOrganExcludeChild(row.id).then(response => {
        this.deptOptions = this.handleTree(response, "id");
      });
    },
    /** 提交按钮 */
    submitForm: function () {
      this.$refs["form"].validate(valid => {
        if (valid) {
          if (this.form.id != undefined) {
            updateOrgan(this.form).then(response => {
              if (response.code === 200) {
                this.msgSuccess("修改成功");
                this.open = false;
                this.getList();
              }
            });
          } else {
            addOrgan(this.form).then(response => {
              if (response.code === 200) {
                this.msgSuccess("新增成功");
                this.open = false;
                this.getList();
              }
            });
          }
        }
      });
    },
    /** 删除按钮操作 */
    handleDelete(row) {
      this.$confirm('是否确认删除名称为"' + row.name + '"的机构?', "警告", {
        confirmButtonText: "确定",
        cancelButtonText: "取消",
        type: "warning"
      }).then(function () {
        return delOrgan(row.id);
      }).then(() => {
        this.getList();
        this.msgSuccess("删除成功");
      }).catch(function () {
      });
    }
  }
};
</script> -->
